![](https://user-images.githubusercontent.com/52009346/69100304-2eb3e800-0a5d-11ea-9a3a-8e502af2120b.png)

[![Open Source Love svg2](https://badges.frapsoft.com/os/v2/open-source.svg?v=103)](https://github.com/pro-well-plan/pwptemp/blob/master/LICENSE.md)
[![PyPI version](https://badge.fury.io/py/pwptemp.svg)](https://badge.fury.io/py/pwptemp)
[![License: LGPL v3](https://img.shields.io/badge/License-LGPL_v3-blue.svg)](https://www.gnu.org/licenses/lgpl-3.0)
[![Webapp](https://img.shields.io/badge/WebApp-On-green.svg)](https://share.streamlit.io/jcamiloangarita/opensource_apps/app.py)
[![Documentation Status](https://readthedocs.org/projects/pwptemp/badge/?version=latest)](http://pwptemp.readthedocs.io/?badge=latest)
[![Downloads](https://pepy.tech/badge/pwptemp)](https://pepy.tech/project/pwptemp)

## Contributors

* **Juan Camilo Gonzalez Angarita** - [jcamiloangarita](https://github.com/jcamiloangarita)
* **Muhammad Suleman** - [msfazal](https://github.com/msfazal)
* **Eirik Lyngvi** - [elyngvi](https://github.com/elyngvi)
* **Magnus Tvedt** - [magnusbj](https://github.com/magnusbj)

See the full list of [contributors](https://github.com/pro-well-plan/pwptemp/graphs/contributors) involved in this project.

## Introduction
Pwptemp is a LGPL licensed library for easy calculation of the
temperature distribution along the well. Features are added as they
are needed; suggestions and contributions of all kinds are very welcome.

To catch up on the latest development and features, see the [changelog](CHANGELOG.md).

## Documentation

See here for the [complete pwptemp package documentation](https://pwptemp.readthedocs.io/en/latest/).

## Getting Started

These instructions will get you a copy of the project up and running on your local machine for development and testing purposes.

### Get pwptemp

* Users: Wheels for Python from [PyPI](https://pypi.python.org/pypi/pwptemp/) 
    * `pip install pwptemp`
* Developers: Source code from [Github](https://github.com/pro-well-plan/pwptemp)
    * `git clone https://github.com/pro-well-plan/pwptemp`

## Quick Use

Take a look at the [tutorial](https://github.com/pro-well-plan/pwptemp/blob/master/Tutorial.md)
to check how to use the different functions available. 
    
## Contributing

Please read [CONTRIBUTING](CONTRIBUTING.md) for details on our code of conduct, and the process for submitting pull requests to us.

## History ##
Pwptemp was initially written and is maintained by [Pro Well Plan
AS](http://www.prowellplan.com/) as a free, simple, easy-to-use way of getting
temperature data that can be tailored to our needs, and as contribution to the
free software community.

## License

This project is licensed under the GNU Lesser General Public License v3.0 - see the [LICENSE](LICENSE.md) file for details


*for further information contact juan@prowellplan.com*
